==> hoteldruid-mod-nl_3.0.3-1.tar.gz: nl/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "De <b>naam</b> van gebruiker"; break;
case "verrà cambiato da":  			$messaggio = "wordt gewijzigd van"; break;
case "a":  					$messaggio = "naar"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "De <b>login</b> van gebruiker"; break;
case "password conservata in chiaro":  		$messaggio = "password bewaard in gewone tekst"; break;
case "password conservata criptata con md5":  	$messaggio = "password gecodeerd bewaard met md5"; break;
case "password conservata criptata con mcrypt":	$messaggio = "password gecodeerd bewaard met mcrypt"; break;
case "password conservata criptata con mhash":	$messaggio = "password gecodeerd bewaard met mhash"; break;
case "disabilitato":  				$messaggio = "niet mogelijk"; break;
case "Inserisci una nuova password":  		$messaggio = "Voeg een nieuw password in"; break;
case "Ripeti la password":  			$messaggio = "Herhaal het password"; break;
case "Continua":  				$messaggio = "Ga verder"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Nuova password dell'utente":  		$messaggio = "Nieuwe password van gebruiker"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "<b>Geen</b> wijzigingen zijn uitgevoerd"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Er bestaat reeds een gebruiker genaamd"; break;
case "Le nuove password non coincidono":  	$messaggio = "Nieuw password komt niet overeen"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Voeg een nieuw password in voor gebruiker"; break;
case "Nuova password":  			$messaggio = "Nieuw password"; break;
case "N°":  					$messaggio = "N°"; break;
case "nome":  					$messaggio = "naam"; break;
case "modifica":  				$messaggio = "wijzig"; break;
case "password criptata con md5":  		$messaggio = "password gecodeerd met md5"; break;
case "password criptata con mcrypt":  		$messaggio = "password gecodeerd meth mcrypt"; break;
case "password criptata con mhash":  		$messaggio = "password gecodeerd met mhash"; break;
case "privilegi":  				$messaggio = "rechten"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Mogelijk maken voor andere gebruikers"; break;
case "Modifica gli utenti":  			$messaggio = "Wijzig gebruikers"; break;
case "Aggiungi":  				$messaggio = "Voeg toe"; break;
case "un nuovo utente chiamato":  		$messaggio = "een nieuwe gebruiker genaamd"; break;
case "dell'utente":  				$messaggio = "of user"; break;
case "del gruppo":  				$messaggio = "of group"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case "Gestione Utenti":  			$messaggio = "Users Management"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Already exists</div> an user called"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">not</div> inserted correctly"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid users management"; break;
case "login":  					$messaggio = "login"; break;
case "password":  				$messaggio = "password"; break;
case "Amministratore":  			$messaggio = "Administrator"; break;
case "dall'utente":  				$messaggio = "from user"; break;
case "Privilegi importati":  			$messaggio = "Privileges imported"; break;
case "Importa":  				$messaggio = "Import"; break;
case "gruppi":  				$messaggio = "groups"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Updated groups of user"; break;
case "Gruppi dell'utente":  			$messaggio = "Groups of user"; break;
case "Nuovo gruppo":  				$messaggio = "New group"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Already exists a group called"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "cancella":  				$messaggio = "delete"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Are you sure you want to <b style=\"font-weight: normal; color: red;\">delete</b> user"; break;
case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizations"; break;
case "solo i privilegi":  			$messaggio = "only privileges"; break;
case "solo le personalizzazioni":  		$messaggio = "only customizations"; break;
case "Personalizzazioni importate":  		$messaggio = "Customizations imported"; break;
case "privilegi, personalizzazioni e gruppi":	$messaggio = "privileges, customizations and groups"; break;
case "privilegi e gruppi":  			$messaggio = "privileges and groups"; break;
case "personalizzazioni e gruppi":  		$messaggio = "customizations and groups"; break;
case "solo i gruppi":  				$messaggio = "only groups"; break;
case "Gruppi importati":  			$messaggio = "Groups imported"; break;
case "Gestione degli utenti":			$messaggio = "Users management"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-nl_3.0.8-1.tar.gz: nl/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "De <b>naam</b> van gebruiker"; break;
case "verrà cambiato da":  			$messaggio = "wordt gewijzigd van"; break;
case "a":  					$messaggio = "naar"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "De <b>login</b> van gebruiker"; break;
case "password conservata in chiaro":  		$messaggio = "password bewaard in gewone tekst"; break;
case "password conservata criptata con md5":  	$messaggio = "password gecodeerd bewaard met md5"; break;
case "password conservata criptata con mcrypt":	$messaggio = "password gecodeerd bewaard met mcrypt"; break;
case "password conservata criptata con mhash":	$messaggio = "password gecodeerd bewaard met mhash"; break;
case "disabilitato":  				$messaggio = "niet mogelijk"; break;
case "Inserisci una nuova password":  		$messaggio = "Voeg een nieuw password in"; break;
case "Ripeti la password":  			$messaggio = "Herhaal het password"; break;
case "Continua":  				$messaggio = "Ga verder"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Already exists</div> an user called"; break;
case "Nuova password dell'utente":  		$messaggio = "Nieuwe password van gebruiker"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "<b>Geen</b> wijzigingen zijn uitgevoerd"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Er bestaat reeds een gebruiker genaamd"; break;
case "Le nuove password non coincidono":  	$messaggio = "Nieuw password komt niet overeen"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Voeg een nieuw password in voor gebruiker"; break;
case "Nuova password":  			$messaggio = "Nieuw password"; break;
case "N°":  					$messaggio = "N°"; break;
case "nome":  					$messaggio = "naam"; break;
case "modifica":  				$messaggio = "wijzig"; break;
case "password criptata con md5":  		$messaggio = "password gecodeerd met md5"; break;
case "password criptata con mcrypt":  		$messaggio = "password gecodeerd meth mcrypt"; break;
case "password criptata con mhash":  		$messaggio = "password gecodeerd met mhash"; break;
case "privilegi":  				$messaggio = "rechten"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Mogelijk maken voor andere gebruikers"; break;
case "Modifica gli utenti":  			$messaggio = "Wijzig gebruikers"; break;
case "Aggiungi":  				$messaggio = "Voeg toe"; break;
case "un nuovo utente chiamato":  		$messaggio = "een nieuwe gebruiker genaamd"; break;
case "dell'utente":  				$messaggio = "of user"; break;
case "del gruppo":  				$messaggio = "of group"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case "Gestione Utenti":  			$messaggio = "Users Management"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">not</div> inserted correctly"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid users management"; break;
case "Gestione degli utenti":			$messaggio = "Users management"; break;
case "login":  					$messaggio = "login"; break;
case "password":  				$messaggio = "password"; break;
case "Amministratore":  			$messaggio = "Administrator"; break;
case "dall'utente":  				$messaggio = "from user"; break;
case "Privilegi importati":  			$messaggio = "Privileges imported"; break;
case "Importa":  				$messaggio = "Import"; break;
case "gruppi":  				$messaggio = "groups"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Updated groups of user"; break;
case "Gruppi dell'utente":  			$messaggio = "Groups of user"; break;
case "Nuovo gruppo":  				$messaggio = "New group"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Already exists a group called"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "cancella":  				$messaggio = "delete"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Are you sure you want to <b style=\"font-weight: normal; color: red;\">delete</b> user"; break;
case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizations"; break;
case "solo i privilegi":  			$messaggio = "only privileges"; break;
case "solo le personalizzazioni":  		$messaggio = "only customizations"; break;
case "Personalizzazioni importate":  		$messaggio = "Customizations imported"; break;
case "privilegi, personalizzazioni e gruppi":	$messaggio = "privileges, customizations and groups"; break;
case "privilegi e gruppi":  			$messaggio = "privileges and groups"; break;
case "personalizzazioni e gruppi":  		$messaggio = "customizations and groups"; break;
case "solo i gruppi":  				$messaggio = "only groups"; break;
case "Gruppi importati":  			$messaggio = "Groups imported"; break;
case "Password aggiornata":  			$messaggio = "Password updated"; break;
case "Password troppo debole":			$messaggio = "Password too weak"; break;
case "almeno":  				$messaggio = "at least"; break;
case "caratteri":  				$messaggio = "characters"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
